@@ -12,7 +12,7 @@ from django.core.exceptions import ValidationError
 from django.core.validators import MaxLengthValidator, MaxValueValidator, MinLengthValidator, \
     MinValueValidator, URLValidator
 from django.db import models
-from django.db.models import OuterRef, Q, Subquery
+from django.db.models import OuterRef, Subquery
 from django.utils.timezone import now
 from django_countries.fields import CountryField
 from markdown import markdown
@@ -306,9 +306,9 @@ class Satellite(models.Model):
         if cached_satellite:
             data_count = cached_satellite['count']
         else:
-            data_count = DemodData.objects.filter(
-                Q(satellite=self.id) | Q(satellite__associated_satellite=self.id)
-            ).count()
+            satellites_list = list(self.associated_with.all().values_list('pk', flat=True))
+            satellites_list.append(self.pk)
+            data_count = DemodData.objects.filter(satellite__in=satellites_list).count()
         return data_count
 
     @property
@@ -326,9 +326,9 @@ class Satellite(models.Model):
 
         :returns: dict with most recent DemodData for this Satellite
         """
-        data = DemodData.objects.filter(
-            Q(satellite=self.id) | Q(satellite__associated_satellite=self.id)
-        ).order_by('-id')[:1]
+        satellites_list = list(self.associated_with.all().values_list('pk', flat=True))
+        satellites_list.append(self.pk)
+        data = DemodData.objects.filter(satellite__in=satellites_list).order_by('-id')[:1]
         if data:
             latest_datum = data[0]
             return {
