@@ -12,10 +12,12 @@ LOGGER = logging.getLogger('db')
 
 def _remove_latest_tle_set(sender, instance, **kwargs):  # pylint: disable=W0613
     """Updates if needed LatestTle entries"""
-    if instance.status in ['re-entered', 'future']:
-        remove_latest_tle_set(satellite_id=instance.pk)
+    if instance.satellite_entry.status in [
+            're-entered', 'future'
+    ] or instance.associated_satellite or not instance.satellite_entry.approved:
+        remove_latest_tle_set(satellite_pk=instance.pk)
     else:
-        update_latest_tle_sets(satellite_ids=[instance.pk])
+        update_latest_tle_sets(satellite_pks=[instance.pk])
 
 
 def _extract_network_obs_id(sender, instance, created, **kwargs):  # pylint: disable=W0613
