@@ -69,7 +69,8 @@ def update_tle_sets():
                 and satellite.satellite_entry.norad_follow_id < 99000):
             catalog_norad_ids.add(satellite.satellite_entry.norad_follow_id)
         # Check if satellite has a NORAD ID that is officially announced
-        elif satellite.satellite_entry.norad_cat_id < 99000:
+        elif (satellite.satellite_entry.norad_cat_id
+              and satellite.satellite_entry.norad_cat_id < 99000):
             catalog_norad_ids.add(satellite.satellite_entry.norad_cat_id)
 
     other_sources = get_tle_sources()
