@@ -2,7 +2,7 @@
 import logging
 from datetime import timedelta
 
-from bootstrap_modal_forms.generic import BSModalCreateView, BSModalUpdateView
+from bootstrap_modal_forms.generic import BSModalCreateView, BSModalFormView, BSModalUpdateView
 from django.conf import settings
 from django.contrib import messages
 from django.contrib.auth import get_user_model
@@ -19,8 +19,8 @@ from django.urls import reverse
 from django.utils.timezone import now
 from django.views.decorators.http import require_POST
 
-from db.base.forms import SatelliteCreateForm, SatelliteUpdateForm, TransmitterCreateForm, \
-    TransmitterUpdateForm
+from db.base.forms import MergeSatellitesForm, SatelliteCreateForm, SatelliteUpdateForm, \
+    TransmitterCreateForm, TransmitterUpdateForm
 from db.base.helpers import get_apikey
 from db.base.models import DemodData, Satellite, SatelliteEntry, SatelliteIdentifier, \
     SatelliteSuggestion, Transmitter, TransmitterEntry, TransmitterSuggestion
@@ -463,24 +463,36 @@ class TransmitterUpdateView(LoginRequiredMixin, BSModalUpdateView):
         return self.request.META.get('HTTP_REFERER')
 
 
-@login_required
-@require_POST
-def merge_satellites(request):
+class MergeSatellitesView(LoginRequiredMixin, BSModalFormView):
     """Merges satellites if user has merge permission.
     """
-    primary_satellite = get_object_or_404(Satellite, pk=request.POST['primary-satellite'])
-    associated_satellite = get_object_or_404(Satellite, pk=request.POST['associated-satellite'])
+    template_name = 'base/modals/satellites_merge.html'
+    form_class = MergeSatellitesForm
 
-    if request.user.has_perm('base.merge_satellites'):
-        if primary_satellite.pk == associated_satellite.pk:
-            messages.error(request, ('Primary and Associated satellites are the same!'))
+    user = get_user_model()
+
+    def dispatch(self, request, *args, **kwargs):
+        self.user = request.user
+        return super().dispatch(request, *args, **kwargs)
+
+    def form_valid(self, form):
+        response = super().form_valid(form)
+
+        if self.user.has_perm('base.merge_satellites'):
+            if not self.request.is_ajax():
+                primary_satellite = form.cleaned_data['primary_satellite']
+                associated_satellite = form.cleaned_data['associated_satellite']
+                associated_satellite.associated_satellite = primary_satellite
+                associated_satellite.save(update_fields=['associated_satellite'])
+                messages.success(self.request, ('Satellites have been merged!'))
         else:
-            associated_satellite.associated_satellite = primary_satellite
-            associated_satellite.save(update_fields=['associated_satellite'])
-            messages.success(request, ('Merge is complete!'))
-    else:
-        messages.error(request, ('No permission to merge satellites!'))
-    return redirect(reverse('satellites'))
+            messages.error(self.request, ('No permission to merge satellites!'))
+            response = redirect(reverse('satellites'))
+
+        return response
+
+    def get_success_url(self):
+        return self.request.META.get('HTTP_REFERER')
 
 
 class SatelliteCreateView(LoginRequiredMixin, BSModalCreateView):
